@@ -202,9 +202,26 @@ class ActionBag(QObject):
         _setShortcut(self.__editNodeIconsAction, settings.get('editNodeIconsShortcut'))
         _setShortcut(self.__foldNodeAction, settings.get('foldNodeShortcut'))
         _setShortcut(self.__addNodeAction, settings.get('addNodeShortcut'))
+        _setShortcut(self.__addSiblingNodeBelowAction,
+                settings.get('addSiblingNodeBelowShortcut'))
+        _setShortcut(self.__addSiblingNodeAboveAction,
+                settings.get('addSiblingNodeAboveShortcut'))
         _setShortcut(self.__removeNodeAction, settings.get('removeNodeShortcut'))
+        _setShortcut(self.__enterTransferModeAction,
+                settings.get('enterTransferModeShortcut'))
+        _setShortcut(self.__cancelTransferModeAction,
+                settings.get('cancelTransferModeShortcut'))
+        _setShortcut(self.__putNodeAction, settings.get('putNodeShortcut'))
+        _setShortcut(self.__putNodeBelowAction, settings.get('putNodeBelowShortcut'))
+        _setShortcut(self.__putNodeAboveAction, settings.get('putNodeAboveShortcut'))
         _setShortcut(self.__editHyperlinkAction, settings.get('editHyperlinkShortcut'))
         _setShortcut(self.__openHyperlinkAction, settings.get('openHyperlinkShortcut'))
+        _setShortcut(self.__selectLeftNodeAction, settings.get('selectLeftNodeShortcut'))
+        _setShortcut(self.__selectRightNodeAction,
+                settings.get('selectRightNodeShortcut'))
+        _setShortcut(self.__selectUpNodeAction, settings.get('selectUpNodeShortcut'))
+        _setShortcut(self.__selectDownNodeAction, settings.get('selectDownNodeShortcut'))
+        _setShortcut(self.__selectRootNodeAction, settings.get('selectRootNodeShortcut'))
 
     def _initializeMaemoActions(self):
         '''Initialize maemo actions'''
