@@ -25,7 +25,7 @@ Core classes
 '''
 
 import hivemind.settings as settings
-import time
+import time, random
 from PyQt4.QtGui import QApplication, QFontMetricsF, QPalette, QTextDocument, \
  QAbstractTextDocumentLayout
 from PyQt4.QtCore import QSizeF
@@ -479,9 +479,8 @@ class Node(Element, Observable):
         self.__nodeAttribute = None
         self.__children = []
         if self.__id is None: #pylint: disable=E0203
-            self.__created = int(time.time() * 1000.0)
-            self.__modified = self.__created
-            self.__id = 'ID_0%d' % id(self)
+            self.__modified = self.__created = int(time.time() * 1000.0)
+            self.__id = 'ID_%d' % random.getrandbits(31)
         # local fields
         self.__isHtmlContent = False
         self.__colorPalette = QPalette()
