@@ -34,7 +34,7 @@ from PyQt4.QtCore import SIGNAL, QRegExp, Qt, QSize, QCoreApplication, QObject
 from hivemind.attribute import readable, adaptCallable
 from hivemind.gui_widgets import SearchingTrMixin, SpecialTextEdit, SettingsCreator, \
 ScalingWidget, IconList, IconTable, LineEditBinder, ColorLabel
-from hivemind.network.network_models import AffiliationDelegate
+from hivemind.network.models import AffiliationDelegate
 from twisted.words.protocols.jabber import jid
 from hivemind.smartconference.kp import SmartSpaceChecker
 
@@ -1110,8 +1110,9 @@ class AffiliationDialog(CommonDialog):
         if not jidRegexp.exactMatch(self.__jidEdit.text()):
             _showJIDErrorDialog(self)
             return
-        self.__model.setAffiliation(jid.internJID(self.__jidEdit.text()),
-                self.__affiliationCombo.itemData(self.__affiliationCombo.currentIndex()))
+        self.__model.updateAffiliation(jid.JID(unicode(self.__jidEdit.text())).userhost(),
+                unicode(self.__affiliationCombo.itemData(
+                        self.__affiliationCombo.currentIndex()).toString()))
         self.__jidEdit.clear()
 
     def _accept(self):
@@ -1121,32 +1122,6 @@ class AffiliationDialog(CommonDialog):
         QDialog.accept(self)
 
 
-class NetworkAuthorizationDialog(QMessageBox):
-    '''
-    Authorization dialog
-    @author: Oleg Kandaurov
-    '''
-
-    readable('mapButton')
-    def __init__(self, requestor, parent = None):
-        '''
-        @type parent: QWidget
-        @param requestor: Entity that requests authorization
-        @type requestor: str
-        '''
-        QMessageBox.__init__(self, parent)
-        self.setIcon(QMessageBox.Question)
-        self.setWindowTitle(self.tr('Participation request'))
-        self.setText(self.tr('%s wants to particapate in teamwork') % requestor)
-        self.setInformativeText(self.tr('Do you want to accept pariticipation request?'))
-        acceptButton = self.addButton(self.tr('Accept'), QMessageBox.AcceptRole)
-        denyButton = self.addButton(self.tr('Deny'), QMessageBox.RejectRole)
-        blockButton = self.addButton(self.tr('Block'), QMessageBox.ActionRole)
-        self.setDefaultButton(acceptButton)
-        self.setEscapeButton(denyButton)
-        self.__mapButton = {acceptButton: 'accept', denyButton: 'deny', blockButton: 'block'}
-
-
 class NetworkSettingsDialog(CommonDialog):
     '''
     Abstract class for network settings dialog
@@ -1297,6 +1272,7 @@ class NetworkConnectionDialog(CommonDialog):
 
     def _adjustConnectionSettings(self):
         '''Adjust connection settings'''
+        #pylint: disable=W0612
         isCustom = self.__customSetting.isChecked()
         self.__hostEdit.setEnabled(isCustom)
         self.__portEdit.setEnabled(isCustom)
@@ -1338,18 +1314,20 @@ class NetworkErrorDialog(QMessageBox):
     @author: Oleg Kandaurov
     '''
 
-    def __init__(self, parent = None):
+    def __init__(self, action, parent = None):
         '''
         Constructor
+        @param action: action for performing
         @type parent: QWidget
         '''
         QMessageBox.__init__(self, parent)
+        self.__action = action
         self.setIcon(QMessageBox.Warning)
         self.setWindowTitle(self.tr('Network error'))
         self.setStandardButtons(QMessageBox.Ok)
         self.setDefaultButton(QMessageBox.Ok)
 
-    def showError(self, info, reason, details):
+    def showError(self, info, reason, details, fatal):
         '''
         Shows specific error information
         @param info: Short information about error type
@@ -1358,7 +1336,15 @@ class NetworkErrorDialog(QMessageBox):
         @type reason: str
         @param details: Technical details
         @type details: str
+        @param fatal: Whether error is fatal or not
+        @type fatal: bool
         '''
+        if not fatal:
+            actionButton = QPushButton(self.tr('Disconnect'))
+            actionButton.clicked.connect(self.__action)
+            self.addButton(actionButton, QMessageBox.ActionRole)
+        else:
+            self.__action()
         self.setText(info)
         self.setInformativeText(reason)
         self.setDetailedText(details)
