@@ -27,7 +27,7 @@ View delegates for core objects
 import math
 from PyQt4.QtCore import QRectF, QPointF, Qt, QObject, pyqtSignal
 from PyQt4.QtGui import QGraphicsScene, QGraphicsItem, QAction, QPen, \
-QPainterPath, QPolygonF, QIcon, QTextDocument
+QPainterPath, QPolygonF, QIcon, QTextDocument, QPainter
 import hivemind.resource as resource
 import hivemind.settings as settings
 from hivemind.attribute import readable, writable
@@ -878,7 +878,9 @@ class NodeDelegate(QGraphicsItem):
                 svgIcon.render(painter, QRectF(xIconPos, yIconPos,
                         NodeDelegate.__ICON_SIZE, NodeDelegate.__ICON_SIZE))
             else:
-                painter.drawImage(QPointF(xIconPos, yIconPos),
+                painter.setRenderHint(QPainter.SmoothPixmapTransform)
+                painter.drawImage(QRectF(xIconPos, yIconPos,
+                        NodeDelegate.__ICON_SIZE, NodeDelegate.__ICON_SIZE),
                         resource.getIconByName(icon))
             xIconPos += NodeDelegate.__ICON_SIZE
         # paint text content
