@@ -28,8 +28,7 @@ GUI factory
 
 from PyQt4.QtGui import QFileDialog
 import hivemind.sysconfig as sysconfig
-from hivemind.dialogs import SideSelectionDialog, NetworkAuthorizationDialog, \
-        NetworkErrorDialog, EditHyperlinkDialog
+from hivemind.dialogs import SideSelectionDialog, NetworkErrorDialog, EditHyperlinkDialog
 
 if sysconfig.PLATFORM == 'maemo':
     from hivemind.maemo.main_window import MaemoMainWindow
@@ -38,6 +37,19 @@ if sysconfig.PLATFORM == 'maemo':
     from hivemind.maemo.dialogs import MaemoSettingsDialog, MaemoNetworkConnectionDialog
     from hivemind.maemo.dialogs import MaemoAffiliationDialog, MaemoFindToolBar
     from hivemind.maemo.dialogs import MaemoNetworkSettingsDialog, MaemoNetworkClientDialog
+    from hivemind.maemo.dialogs import MaemoNetworkMainDialog
+
+    '''Default parent for network dialogs on Maemo'''
+    __defaultNetworkParent = None
+
+    def createMaemoNetworkMainDialog(actionBag, parent):
+        '''
+        Creates main network dialog for Maemo
+        '''
+        global __defaultNetworkParent #pylint: disable=W0603
+        __defaultNetworkParent = MaemoNetworkMainDialog(actionBag, parent)
+        return __defaultNetworkParent
+
 else:
     from hivemind.desktop.main_window import DesktopMainWindow
     from hivemind.desktop.dialogs import DesktopEditNodeDialog, DesktopEditLabelDialog
@@ -143,22 +155,15 @@ def createAffiliationDialog(model):
     Factory for creating families of related side affiliation dialogs
     '''
     if sysconfig.PLATFORM == 'maemo':
-        return MaemoAffiliationDialog(model, __defaultParent)
+        return MaemoAffiliationDialog(model, __defaultNetworkParent)
     return DesktopAffiliationDialog(model, __defaultParent)
 
-def createNetworkAuthorizationDialog(requestor):
-    '''
-    Factory for creating families of network authorization dialogs
-    @type requestor: str
-    '''
-    return NetworkAuthorizationDialog(requestor, __defaultParent)
-
 def createNetworkSettingsDialog():
     '''
     Factory for creating families of related network settings dialogs
     '''
     if sysconfig.PLATFORM == 'maemo':
-        return MaemoNetworkSettingsDialog(__defaultParent)
+        return MaemoNetworkSettingsDialog(__defaultNetworkParent)
     return DesktopNetworkSettingsDialog(__defaultParent)
 
 def createNetworkClientDialog(rosterModel):
@@ -166,7 +171,7 @@ def createNetworkClientDialog(rosterModel):
     Factory for creating families of related client dialogs
     '''
     if sysconfig.PLATFORM == 'maemo':
-        return MaemoNetworkClientDialog(rosterModel, __defaultParent)
+        return MaemoNetworkClientDialog(rosterModel, __defaultNetworkParent)
     return DesktopNetworkClientDialog(rosterModel, __defaultParent)
 
 def createNetworkConnectionDialog():
@@ -174,14 +179,14 @@ def createNetworkConnectionDialog():
     Factory for creating families of related network connection dialogs
     '''
     if sysconfig.PLATFORM == 'maemo':
-        return MaemoNetworkConnectionDialog(__defaultParent)
+        return MaemoNetworkConnectionDialog(__defaultNetworkParent)
     return DesktopNetworkConnectionDialog(__defaultParent)
 
-def createNetworkErrorDialog():
+def createNetworkErrorDialog(action):
     '''
     Factory for creating families of network error dialogs
     '''
-    return NetworkErrorDialog(__defaultParent)
+    return NetworkErrorDialog(action, __defaultParent)
 
 def createEditHyperlinkDialog(node, curdir):
     '''
