@@ -30,8 +30,8 @@ import sys
 
 from qt4reactor import qt4reactor
 qt4reactor.install()
-from hivemind.network import network_core
-network_core.startReactor()
+import hivemind.network.core
+hivemind.network.core.startReactor()
 
 import getopt
 import os
@@ -91,7 +91,7 @@ class MainWindowController(QObject):
         self.__mindMapScene.currentNodeChanged.connect(adaptCallable(self._setActionsState))
         self.__mainWindow = gui_factory.createMainWindow(self.__actionBag, self.__mindMapScene)
         self.__mindMapController = MindMapController(self.__mindMapScene, self.__actionBag)
-        self.__networkController = network_core.NetworkController(
+        self.__networkController = hivemind.network.core.NetworkController(
                 self.__mindMapController, self.__actionBag)
         self.__smartConferenceRobot = SmartConferenceRobot(self.__mindMapScene,
                 self.__networkController, self.__actionBag)
@@ -103,7 +103,7 @@ class MainWindowController(QObject):
                 adaptCallable(self.onItemClicked))
         self.__mainWindow.closeEvnt.connect(self._closeEvent)
         splashScreen.finish(self.__mainWindow)
-        self.__mainWindow.showMaximized()
+        self.__mainWindow.showNormal()
         _configureApplication(self.__mindMapController)
 
     def _setActionsState(self, currentNode):
@@ -589,7 +589,7 @@ class MindMapController(QObject):
         self.__actionBag = actionBag
         self.__undoStack = None
         self.__initialMindMap = None
-        self._loadUndoStack(QUndoStack())
+        self.loadUndoStack(QUndoStack())
         self.__fileName = None
         self.__autosaved = False
         self.__autosaveTimer = QTimer(self)
@@ -606,7 +606,7 @@ class MindMapController(QObject):
         for action in self.__actionBag.recentFileActions:
             action.triggered.connect(self.openRecentFile)
 
-    def _loadUndoStack(self, undoStack):
+    def loadUndoStack(self, undoStack):
         '''
         Load new undo stack
         @param undoStack: UndoStack to be loaded
@@ -621,15 +621,6 @@ class MindMapController(QObject):
                 self.__actionBag.redoAction.setEnabled))
         self.__undoStack.cleanChanged.connect(adaptCallable(self._undoStackStateChanged))
 
-    def loadUndoStackFromNetwork(self, stack):
-        '''
-        Deserialize stack and load it
-        @param stack: serialized stack
-        @type stack: str
-        '''
-        self._loadUndoStack(parser.deserializeCommandStack(stack,
-                self.__mindMapScene.mindMap))
-
     def _autosaveMindMap(self):
         '''Autosave current map'''
         if self.__undoStack.canUndo():
@@ -762,31 +753,32 @@ class MindMapController(QObject):
                     unicode(args[1]))
             return False
 
-    def performCommandFromNetwork(self, command):
+    def deserializeData(self, data, dataType):
         '''
-        Deserialize, execute and store command received from network
-        @param command: serialized command
-        @type command: str
+        Deserialize data according to the type
+        @param data: serialized data
+        @param type: type of data
+        @return: deserialized data
         '''
-        command = parser.deserializeCommand(command, self.__mindMapScene.mindMap)
-        self.executeCommand(command)
-        self.storeCommand(command)
+        if dataType == 'command':
+            return parser.deserializeCommand(data, self.__mindMapScene.mindMap)
+        elif dataType == 'mindmap':
+            return parser.mindMapFromString(data)
+        elif dataType == 'undostack':
+            return parser.deserializeCommandStack(data, self.__mindMapScene.mindMap)
 
-    def storeCommand(self, command):
-        '''
-        Store command in undo stack if possible
-        @param command: command to store
-        '''
-        if isinstance(command, QUndoCommand):
-            self.__undoStack.push(command)
-
-    def executeCommand(self, command):
+    def executeCommand(self, command, store = True):
         '''
         Execute command, created outside main controller
         @param command: command to execute
+        @param store: whether to store command in undo stack or not
+        @type store: bool
         '''
         if isinstance(command, QUndoCommand):
-            command.redo()
+            if store:
+                self.__undoStack.push(command)
+            else:
+                command.redo()
         elif isinstance(command, ActionCommand):
             {'undo': self.__undoStack.undo, 'redo': self.__undoStack.redo}[command.action]()
         elif isinstance(command, CurrentNodeCommand):
@@ -894,23 +886,18 @@ class MindMapController(QObject):
                     os.path.split(path)[1])
             return
         self._setFileName(path)
-        self._loadMindMap(mindMap)
+        self.loadMindMap(mindMap, False)
         settings.addRecentFile(path)
 
-    def loadMindMapFromNetwork(self, mindMap):
-        '''
-        Deserialize received mind map and load it
-        @param mindMap: Serialized mind map
-        @type mindMap: str
-        '''
-        self._setFileName(None)
-        self._loadMindMap(parser.mindMapFromString(mindMap))
-
-    def _loadMindMap(self, mindMap):
+    def loadMindMap(self, mindMap, resetName = True):
         '''
         Load mindmap into scene
         @type mindMap: MindMap
+        @param resetName: Whether mindmap name must be cleaned or not
+        @type resetName: bool
         '''
+        if resetName:
+            self._setFileName(None)
         self.__initialMindMap = mindMap
         self.__undoStack.setClean()
         self.__undoStack.clear()
