@@ -23,7 +23,6 @@
 '''
 Helper widgets
 '''
-
 import hivemind.settings as settings
 import hivemind.resource as resource
 import math
@@ -33,12 +32,13 @@ QAction, QUndoCommand, QLineEdit, QSpinBox, QCheckBox, QComboBox, QLabel, \
 QToolButton, QIcon, QApplication, QFormLayout, QFontComboBox, QFontDatabase, \
 QHBoxLayout, QGraphicsBlurEffect, QFrame, QPalette, QPushButton, \
 QColorDialog, QPainter, QKeyEvent, QPixmap, QListView, QKeySequence, QToolBar, \
-QFont
+QFont, QButtonGroup, QRadioButton
 from hivemind.attribute import readable
 from PyQt4.QtCore import QAbstractAnimation, QObject, SIGNAL, QLocale, Qt, \
 QRect, QEvent, QRectF, QSize, QParallelAnimationGroup, QPropertyAnimation, \
 QPointF, QRegExp, QSequentialAnimationGroup, QEasingCurve, QTimer, pyqtSignal
 from hivemind.gui_delegates import NodeFinder
+from hivemind.network.models import AffiliationModel
 
 
 class SearchingTrMixin(object):
@@ -857,19 +857,16 @@ class SettingsCreator(QObject):
     def _createAccessModel(self):
         '''Create accessModel component'''
         accessModels = [{self.tr('Open'): 'open'},
-                {self.tr('Interactive'): 'authorize'},
-                {self.tr('Contact list'): 'roster'},
                 {self.tr('White list'): 'whitelist'}]
-        binder = ComboBoxBinder('accessModel', settings.get('accessModel'), accessModels)
+        binder = RadioButtonBinder('accessModel', settings.get('accessModel'), accessModels)
         self.__mainLayout.addRow(self.tr('Trust level'), binder)
         self.__component['accessModel'] = binder
 
     def _createDefaultAffiliation(self):
         '''Create defaultAffiliation component'''
-        affiliations = [{self.tr('None'): 'outcast'},
-                {self.tr('Restricted'): 'member'},
-                {self.tr('Full'): 'publisher'},
-                {self.tr('Owner'): 'owner'}]
+        affiliations = []
+        for value, name in AffiliationModel().mapAffiliations.iteritems():
+            affiliations.append({name: value})
         binder = ComboBoxBinder('defaultAffiliation', settings.get('defaultAffiliation'),
                 affiliations)
         self.__mainLayout.addRow(self.tr('Default permission'), binder)
@@ -1053,6 +1050,48 @@ class LineEditBinder(QLineEdit, ComponentBinder):
         return False
 
 
+class RadioButtonBinder(QWidget, ComponentBinder):
+    '''
+    @author: Oleg Kandaurov
+    '''
+
+    def __init__(self, paramName, value, data, parent = None):
+        '''
+        Initialize radio button binder
+        @param paramName: Parameter that is binded to component
+        @type paramName: str
+        @param value: Initial string
+        @type value: str
+        @param data: Possible radio buttons values
+        @type data: list of dicts
+        @type parent: QWidget
+        '''
+        QWidget.__init__(self, parent)
+        ComponentBinder.__init__(self, paramName, parent)
+        self.__group = QButtonGroup()
+        self.__data = data
+        layout = QHBoxLayout()
+        for values in data:
+            name = values.keys().pop()
+            val = values.values().pop()
+            button = QRadioButton(name)
+            layout.addWidget(button)
+            self.__group.addButton(button)
+            button.toggled.connect(self._buttonChanged)
+            if val == value:
+                button.setChecked(True)
+        self.setLayout(layout)
+
+    def _buttonChanged(self):
+        '''Set value according to radio button'''
+        currentName = self.__group.checkedButton().text()
+        for values in self.__data:
+            name = values.keys().pop()
+            val = values.values().pop()
+            if name == currentName:
+                self._setValue(val)
+
+
 class ShortcutEditBinder(QLineEdit, ComponentBinder):
     '''
     QLineEdit binder for shortcut setup
@@ -1228,8 +1267,8 @@ class ComboBoxBinder(QComboBox, ComponentBinder):
     def _setValue(self, index):
         '''
         Sets new value
-        @param value: index in combo box
-        @type value: int
+        @param index: index in combo box
+        @type index: int
         '''
         self._value = self.__data[index].values().pop()
 
