@@ -29,8 +29,9 @@ from PyQt4.QtGui import QAction, QIcon, QMainWindow, QApplication
 from hivemind.main_window import MainView, AbstractMainWindow
 from hivemind.gui_widgets import MaemoSidePanel, FullScreenExitButton, MaemoNodeMenu
 from hivemind.attribute import readable
+import hivemind
 import hivemind.settings as settings
-from hivemind.maemo.dialogs import MaemoExtendedMenuDialog, MaemoNetworkMainDialog
+from hivemind.maemo.dialogs import MaemoExtendedMenuDialog
 from hivemind.smartconference.kp import M3_AVAILABLE
 
 
@@ -90,8 +91,6 @@ class MaemoMainWindow(AbstractMainWindow):
                 self.tr('&Full screen'), self)
         self.__fullScreenExitButton = FullScreenExitButton(self)
         self.__fullScreenAction.triggered.connect(self.showFullScreen)
-        networkDialog = MaemoNetworkMainDialog(actionBag, self)
-        actionBag.connectionStatusAction.triggered.connect(networkDialog.exec_)
         self.__contextMenu = self._createContextMenu()
         self.__additionalContextMenu = self._createAdditionalContextMenu()
         self._configureContextMenuSubstitution()
@@ -100,6 +99,8 @@ class MaemoMainWindow(AbstractMainWindow):
         self.setAttribute(Qt.WA_Maemo5StackedWindow)
         self.__mindMapView.setVerticalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
         self.__mindMapView.setHorizontalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
+        networkDialog = hivemind.gui_factory.createMaemoNetworkMainDialog(actionBag, self)
+        actionBag.connectionStatusAction.triggered.connect(networkDialog.exec_)
 
     def _createSidePanel(self):
         '''Create side panel'''
