@@ -35,7 +35,7 @@ from PyQt4.QtCore import QFile, QIODevice, QTextStream
 from PyQt4.QtGui import QTextDocument, QColor, QFont, QUndoStack
 from hivemind.core import Node, MindMap, Cloud, Attribute, AttributeRegistry
 from hivemind.commands import AddNodeCommand, MoveNodeCommand, RemoveNodeCommand, \
-StateModificationCommand, ActionCommand, CurrentNodeCommand
+StateModificationCommand, ActionCommand, CurrentNodeCommand, ShutdownCommand
 
 
 def _parseNode(root, parent = None):
@@ -571,6 +571,18 @@ def _fillCurrentNodeCommandElement(command, commandElement):
     '''
     commandElement.append(xml.Element('node', id = command.node.id))
 
+def _fillShutdownCommandElement(command, commandElement):
+    '''
+    Add required content to string XML element
+
+    @param command: command object
+    @type command: ShutdownCommand
+
+    @param commandElement: XML element for processing
+    @type commandElement: lxml Element
+    '''
+    commandElement.append(xml.Element('reason', reason = command.reason))
+
 def _commandToXml(command):
     '''
     Create lxml Element from command object
@@ -697,6 +709,15 @@ def _deserializeCurrentNodeCommand(commandElement, mindMap):
     node = mindMap.getNodeById(nodeElement.get('id'))
     return CurrentNodeCommand(node)
 
+def _deserializeShutdownCommand(commandElement, mindMap):
+    '''
+    Deserialize shutdown command from XML string
+
+    @rtype: ShutdownCommand
+    '''
+    nodeElement = commandElement[0]
+    return ShutdownCommand(nodeElement.get('reason'))
+
 def _xmlToCommand(commandElement, mindMap):
     '''
     Create command object from lxml Element
